from uuid import UUID

import fastapi

from .schemas import UserBaseSchema
from .ctrl import UserController


router = fastapi.APIRouter(prefix='/users', tags=['User'])
ctrl = UserController()


@router.get('')
async def get_users(query: UserBaseSchema = fastapi.Depends()):
    return await ctrl.get_list(**query.model_dump(exclude_none=True))


@router.get('/{id}')
async def get_user(id: UUID):
    return await ctrl.get(id)


@router.post('')
async def create_user(body: UserBaseSchema):
    return await ctrl.create(**body.model_dump(exclude_none=True))


@router.patch('/{id}')
async def update_user(id: UUID, body: UserBaseSchema):
    return await ctrl.update(id, **body.model_dump(exclude_none=True))


@router.delete('/{id}')
async def delete_user(id: UUID):
    return await ctrl.delete(id)
